#!/usr/bin/perl
#
# getURL version 1.0.0
#
# A real simple Perl function to grab a file from an HTTP URL. This won't
# work with other types of URLs such as FTP, FILE, LDAP, etc. The file
# will be saved locally at the specified location. A return value of 0
# indicates an error. Note that no attempt is made to adjust  EOL values
# in the retrieved HTML file to match the local environment.
#
# http://www.ncc.com/freeware/
#
# Copyright (c) 1999, 2000 by R. Steven Rainwater <rsr@ncc.com>
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#==========================================================================
use strict;
use Socket;
use FileHandle;

# Sample use of getURL
print "\n", getURL('http://www.ncc.com/index.html','test.txt'), " bytes saved\n\n";

# function urlSize -- get the file size
sub getURL {
    my $result = '';

    # Parse server and request data
    shift  =~ /^http:\/\/(.*?)(\/.*)/;
    my ($http_server,$http_request) = ($1,$2);
    unless ($http_request) { $http_request = '/'; }

    my $local_filename = shift;

    # Set up the socket and make a connection
    my $iaddr = inet_aton($http_server);
    my $paddr = sockaddr_in(80, $iaddr);
    socket(SOCKET, PF_INET, SOCK_STREAM, getprotobyname('tcp'));
    connect(SOCKET, $paddr) || return 0;
    SOCKET->autoflush(1);
    
    # Send the request and store the file
    print SOCKET "GET $http_request HTTP/1.0\r\nHost: $http_server:80\r\n\r\n";
    while(<SOCKET>) { $result .= $_ }
    close(SOCKET);

    # Strip HTTP header
    $result =~ s/^.*\r\n\r\n//s;
    
    # Save the file and return byte count
    unless (open LFILE, ">$local_filename") { return 0; }
    print LFILE $result;
    close LFILE;
    return length $result;
}
